
"""
DOC
"""

from __future__ import print_function

import argparse
from Bio import SeqIO

import bepipred2 as bp

def entry():
    parser = argparse.ArgumentParser()
    parser.add_argument('fastafile', help='Fasta file containing antigen(s)')
    parser.add_argument('-t', '--threshold', help='Threshold on when to consider residues, epitope residues', 
        type=float, default=0.5)
    args = parser.parse_args()

    antigens = list(SeqIO.parse(args.fastafile,'fasta'))

    #Initialise model
    bp.utils.RF_MODEL = bp.utils.init_rf()

    #Predict all
    for obj in antigens:
        AG = bp.Antigen(obj.id, obj.seq)
        try:
            AG.pred_netsurfp()
            AG.get_features()
            AG.predict()
            print('##### BepiPred-2.0 {} #####'.format(AG.entry_name))
            print('#Entry\tPos\tAA\tRSA\tHelix\tSheet\tCoil\tPred\tEpi')
            for pos in xrange(len(AG.sequence)):
                epi = '.'
                if AG.predicted[pos] > args.threshold:
                    epi = 'E'
                printme = [AG.entry_name, str(pos+1), AG.sequence[pos], str(AG.netsurfp[pos+1][0][1])] + AG.netsurfp[pos+1][1][1:] + [AG.predicted[pos]] + [epi]
                print('\t'.join([ x if type(x) == str else '{:.5f}'.format(x) for x in printme]))
        except bp.BPFeatureError:
            err = 'NetsurfP ({}) failed to predict: {}\n{}'
            raise bp.BPFeatureError(err.format(bp.utils.NETSURFP_BIN,AG.entry_name, AG.sequence))
        except bp.BPPredictError:
            err = 'RandomForest failed to predict: {}\n{}'
            raise bp.BPPredictError(err.format(AG.entry_name, AG.sequence))
        except:
            print('#{} Failed'.format(obj.id))



if __name__ == '__main__':
    entry()
